use crate::base;
use axum::Router;
use axum::{extract::Path, routing::get};
use maud::{html, Markup};

use super::tasks::{self, Task};

pub fn router() -> Router {
    Router::new()
        .route("/", get(index))
        .route("/:id", get(task))
}

pub async fn index() -> Markup {
    let tasks = tasks::all().await;

    match tasks {
        Some(tasks) => index_tmpl(tasks),
        None => base::error_tmpl(),
    }
}

fn index_tmpl(tasks: Vec<Task>) -> Markup {
    html! {
        div class="table-container" {
            table class="table is-hoverable is-fullwidth" {
                thead {
                    tr {
                        th { "Task" }
                        th { "Title" }
                        th { "Status" }
                        th { "Priority" }
                        th {}
                    }
                }
                tbody {
                    @for task in &tasks{
                        tr {
                            th { (task.id) }
                            td { span class="tag is-black" { (task.label) } (task.title) }
                            td { (task.status) }
                            td { (task.priority) }
                            td { button hx-get={ (format!("/tasks/{}", task.id)) } hx-push-url="true" hx-target="closest main" { "Read more" } }
                        }
                    }
                }
            }
        }
    }
}

async fn task(Path(id): Path<i32>) -> Markup {
    let task = tasks::by_id(id).await;

    match task {
        Some(task) => task_tmpl(task),
        None => base::error_tmpl(),
    }
}

fn task_tmpl(task: Task) -> Markup {
    html! {
        h2 { (task.title) }
        button hx-get="/tasks" hx-target="closest main" {
            "Go back"
        }
        hr;
    }
}
